=======================================
Bradley-Terry Time-varying model (BTTV)
=======================================

.. image:: https://badge.fury.io/py/bttv.png
    :target: http://badge.fury.io/py/bttv

.. image:: https://travis-ci.org/shamindras/bttv.png?branch=master
    :target: https://travis-ci.org/shamindras/bttv

bttv


Features
========

* Contains required utilities used to implement
  the Bradley-Terry time-varying methodology
  described in [#BLSR]_.


References
===========

.. [#BLSR] Heejong Bong, Wanshan Li, Shamindra Shrotriya, and Alessandro Rinaldo. "Nonparametric Estimation in the Dynamic Bradley-Terry Model." The 23rd International Conference on Artificial Intelligence and Statistics. 2020.



